@@ -198,7 +198,7 @@ void KateRenderer::paintTextLineBackground(QPainter &paint, KateLineLayoutPtr la
     uint mrk = m_doc->mark(layout->line());
     if (mrk) {
         for (uint bit = 0; bit < 32; bit++) {
-            KTextEditor::MarkInterface::MarkTypes markType = (KTextEditor::MarkInterface::MarkTypes)(1 << bit);
+            KTextEditor::MarkInterface::MarkTypes markType = (KTextEditor::MarkInterface::MarkTypes)(1U << bit);
             if (mrk & markType) {
                 QColor markColor = config()->lineMarkerColor(markType);
 
